Zarr
====

Zarr is a Python package providing an implementation of compressed,
chunked, N-dimensional arrays, designed for use in parallel
computing. See the `documentation <http://zarr.readthedocs.io/>`_ for
more information.

.. image:: https://badges.gitter.im/zarr-developers/community.svg
    :target: https://gitter.im/zarr-developers/community

.. image:: https://readthedocs.org/projects/zarr/badge/?version=latest
    :target: http://zarr.readthedocs.io/en/latest/?badge=latest

.. image:: https://travis-ci.org/zarr-developers/zarr.svg?branch=master
    :target: https://travis-ci.org/zarr-developers/zarr

.. image:: https://ci.appveyor.com/api/projects/status/7d4iko59k8hpbbik?svg=true
    :target: https://ci.appveyor.com/project/zarr-developers/zarr

.. image:: https://coveralls.io/repos/github/zarr-developers/zarr/badge.svg?branch=master
    :target: https://coveralls.io/github/zarr-developers/zarr?branch=master
